pub struct FallbackTextMeasurer;Expand description
Fallback text measurer.
This implementation does not rely on any font engine. It uses a simple heuristic based on font size and character count. Intended for testing, bring-up, and environments without font support.